aboutsummaryrefslogtreecommitdiffstats
path: root/src/quick/items/qquickpincharea.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/quick/items/qquickpincharea.cpp')
-rw-r--r--src/quick/items/qquickpincharea.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/quick/items/qquickpincharea.cpp b/src/quick/items/qquickpincharea.cpp
index 848e887fba..d167d75efb 100644
--- a/src/quick/items/qquickpincharea.cpp
+++ b/src/quick/items/qquickpincharea.cpp
@@ -40,7 +40,7 @@
****************************************************************************/
#include "qquickpincharea_p_p.h"
-#include "qquickcanvas.h"
+#include "qquickwindow.h"
#include <QtGui/qevent.h>
#include <QtGui/qguiapplication.h>
@@ -285,7 +285,7 @@ void QQuickPinchArea::touchEvent(QTouchEvent *event)
// A common non-trivial starting scenario is the user puts down one finger,
// then that finger remains stationary while putting down a second one.
// However QQuickCanvas will not send TouchUpdates for TouchPoints which
// were not initially accepted; that would be inefficient and noisy.
// So even if there is only one touchpoint so far, it's important to accept it
// in order to get updates later on (and it's accepted by default anyway).
@@ -416,7 +416,7 @@ void QQuickPinchArea::updatePinch()
if (pe.accepted()) {
d->inPinch = true;
d->stealMouse = true;
- QQuickCanvas *c = canvas();
+ QQuickWindow *c = window();
if (c && c->mouseGrabberItem() != this)
grabMouse();
setKeepMouseGrab(true);
@@ -285,7 +285,7 @@ void QQuickPinchArea::touchEvent(QTouchEvent *event)
// A common non-trivial starting scenario is the user puts down one finger,
// then that finger remains stationary while putting down a second one.
- // However QQuickCanvas will not send TouchUpdates for TouchPoints which
+ // However QQuickWindow will not send TouchUpdates for TouchPoints which
// were not initially accepted; that would be inefficient and noisy.
// So even if there is only one touchpoint so far, it's important to accept it